==> Mapster-1.4.3.zip: Mapster/Locale/frFR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "frFR")
if not L then return end

L["(Mini) Disable Mouse"] = "(Mini) Désactiver souris"
L["(Mini) Hide Border"] = "(Mini) Cacher bordures"
L["Accuracy"] = "Précision"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Modifie la taille de la flèche du joueur sur la carte pour une meilleure visibilité."
L["Alpha"] = "Transparence"
L["BattleMap"] = "CarteLocale"
L["Battlegrounds"] = "Champs de bataille"
L["Blobs & Panels"] = "Spots et panneaux"
L["Burning Crusade Instances"] = "Instances de Burning Crusade" -- Needs review
L["Burning Crusade Raids"] = "Raids de Burning Crusade" -- Needs review
L["Cataclysm Instances"] = "Instances de Cataclysm"
L["Cataclysm Raids"] = "Raids de Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Modifiez l'échelle de la carte du monde si vous ne souhaitez pas que tout votre écran soit occupé quand la carte est ouverte."
L["Classic Instances"] = "Instances classiques"
L["Classic Raids"] = "Raids classiques"
L["Coordinates"] = "Coordonnées"
L["Cursor"] = "Curseur "
L["Debug"] = "Débogage"
L["Disable Mouse"] = "Désactiver la souris"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale minimisée évitant ainsi, par exemple, de changer de zone."
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale évitant ainsi, par exemple, de changer de zone."
L["Enable BattleMap"] = "Activer CarteLocale"
L["Enable Coordinates"] = "Activer coordonnées"
L["Enable FogClear"] = "Activer antibrouillard"
L["Enable Group Icons"] = "Activer icônes de groupe"
L["Enable Instance Maps"] = "Activer les cartes d'instance"
L["FogClear"] = "Antibrouillard"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "Antibrouillard enregistre les nouvelles données dans votre propre SavedVariables, mais ces données peuvent devenir corrompues (ou tout simplement obsolètes) avec un nouveau patch. Réinitialisez les données si une des cartes du monde semble corrompue."
L["Group Icons"] = "Icônes de groupe"
L["Hide Border"] = "Cacher les bordures"
L["Hide Completely"] = "Cacher complètement"
L["Hide Map Button"] = "Cacher le bouton de la carte"
L["Hide Textures"] = "Cacher les textures"
L["Hide the borders of the big map."] = "Cache les bordures de la grande carte."
L["Hide the borders of the minimized map."] = "Cache les bordures de la carte minimisée."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Cache les textures entourant la CarteLocale, ne laissant que la carte en elle-même."
L["Instance Maps"] = "Cartes d'instance"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster vous permet de contrôler divers aspects de la carte du monde. Vous pouvez modifier son style, contrôler les plugins qui lui ajoutent de nouvelles fonctionnalités, et configurer différents profils pour tous vos personnages."
L["Minimized Alpha"] = "Transp. quand minimisée"
L["Minimized Scale"] = "Échelle quand minimisée"
L["Note: You need to reload your UI after reseting the data!"] = "Note : rechargez votre IU après la réinitialisation des données !"
L["Only WorldMap Blobs"] = "Seulement les spots"
L["Overlay Color"] = "Couleur de superposition"
L["POI Scale"] = "Échelle des POIs"
L["Player"] = "Joueur "
L["PlayerArrow Scale"] = "Échelle flèche du joueur"
L["Quest Objectives"] = "Objectifs de quête"
L["Reset FogClear Data"] = "RÀZ des données"
L["Scale"] = "Échelle"
L["Scale of the POI Icons on the Map."] = "Définit l'échelle des icônes des points d'intérêt sur la carte."
L["Scale of the big map."] = "Définit l'échelle de la grande carte."
L["Scale of the minimized map."] = "Définit l'échelle de la carte minimisée."
L["Size on the Battle Map"] = "Taille sur la carte de bataille"
L["Size on the World Map"] = "Taille sur la carte du monde"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Le module CarteLocale vous permet de changer le style de la carte locale (ou tactique) en enlevant les textures inutiles ou les objectifs JcJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Le module des coordonnées ajoute sur la fenêtre de la carte du monde les coordonnées actuelles de votre personnage ainsi que ceux de votre curseur."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Le module d'antibrouillard enlève le brouillard de guerre de la carte du monde, affichant ainsi tout ce qui se trouve dans les zones qui vous sont inconnues."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Le module Icônes de groupe vous permet de redimensionner les icônes du groupe et du raid de la carte du monde."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Le module des cartes d'instance vous permet de voir les cartes des champs de bataille et des instances du jeu sans être dans forcément dans ces instances."
L["The transparency of the big map."] = "Définit la transparence de la grande carte."
L["The transparency of the minimized map."] = "Définit la transparence de la carte minimisée."
L["Turn on debugging for the FogClear Module."] = "Active le débogage pour le module Antibrouillard."
L["Wrath Instances"] = "Instances de Lich King"
L["Wrath Raids"] = "Raids de Lich King"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Vous pouvez modifier la transparence de la carte du monde afin de continuer à voir l'environnement du jeu quand vous consultez la carte."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Vous pouvez ici déterminer la précision des coordonnées. Par exemple, si vous voulez des coordonnées très précises, mettez la valeur à 2."

==> Mapster-1.5.6.1.zip: Mapster/Locale/frFR.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "frFR")
if not L then return end

L["Accuracy"] = "Précision"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Modifie la taille de la flèche du joueur sur la carte pour une meilleure visibilité."
L["Alpha"] = "Transparence"
L["Battlegrounds"] = "Champs de bataille"
L["BattleMap"] = "CarteLocale"
L["Blobs & Panels"] = "Spots et panneaux"
L["Burning Crusade Instances"] = "Instances de Burning Crusade" -- Needs review
L["Burning Crusade Raids"] = "Raids de Burning Crusade" -- Needs review
L["Cataclysm Instances"] = "Instances de Cataclysm"
L["Cataclysm Raids"] = "Raids de Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Modifiez l'échelle de la carte du monde si vous ne souhaitez pas que tout votre écran soit occupé quand la carte est ouverte."
L["Classic Instances"] = "Instances classiques"
L["Classic Raids"] = "Raids classiques"
L["Coordinates"] = "Coordonnées"
L["Cursor"] = "Curseur "
L["Debug"] = "Débogage"
L["Disable Mouse"] = "Désactiver la souris"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale évitant ainsi, par exemple, de changer de zone."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Désactive l'interactivité de la souris avec la carte principale minimisée évitant ainsi, par exemple, de changer de zone."
L["EJ Icon Scale"] = "Échelle icônes codex" -- Needs review
L["Enable BattleMap"] = "Activer CarteLocale"
L["Enable Coordinates"] = "Activer coordonnées"
L["Enable FogClear"] = "Activer antibrouillard"
L["Enable Group Icons"] = "Activer icônes de groupe"
L["Enable Instance Maps"] = "Activer les cartes d'instance"
L["FogClear"] = "Antibrouillard"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "Antibrouillard enregistre les nouvelles données dans votre propre SavedVariables, mais ces données peuvent devenir corrompues (ou tout simplement obsolètes) avec un nouveau patch. Réinitialisez les données si une des cartes du monde semble corrompue."
L["Group Icons"] = "Icônes de groupe"
L["Hide Border"] = "Cacher les bordures"
L["Hide Completely"] = "Cacher complètement"
L["Hide Map Button"] = "Cacher le bouton de la carte"
-- L["Hide Quest Panels"] = "Hide Quest Panels"
L["Hide Textures"] = "Cacher les textures"
L["Hide the borders of the big map."] = "Cache les bordures de la grande carte."
L["Hide the borders of the minimized map."] = "Cache les bordures de la carte minimisée."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Cache les textures entourant la CarteLocale, ne laissant que la carte en elle-même."
L["Instance Maps"] = "Cartes d'instance"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster vous permet de contrôler divers aspects de la carte du monde. Vous pouvez modifier son style, contrôler les plugins qui lui ajoutent de nouvelles fonctionnalités, et configurer différents profils pour tous vos personnages."
L["(Mini) Disable Mouse"] = "(Mini) Désactiver souris"
L["(Mini) Hide Border"] = "(Mini) Cacher bordures"
L["Minimized Alpha"] = "Transp. quand minimisée"
L["Minimized Scale"] = "Échelle quand minimisée"
L["Note: You need to reload your UI after reseting the data!"] = "Note : rechargez votre IU après la réinitialisation des données !"
L["Only WorldMap Blobs"] = "Seulement les spots"
L["Overlay Color"] = "Couleur de superposition"
L["Pandaria Instances"] = "Instances de Pandaria" -- Needs review
L["Pandaria Raids"] = "Raids de Pandaria" -- Needs review
L["Player"] = "Joueur "
L["PlayerArrow Scale"] = "Échelle flèche du joueur"
L["POI Scale"] = "Échelle des POIs"
L["Reset FogClear Data"] = "RÀZ des données"
L["Scale"] = "Échelle"
L["Scale of the big map."] = "Définit l'échelle de la grande carte."
L["Scale of the Encounter Journal Icons on the Map."] = "Échelle des icônes du codex des donjons sur la carte." -- Needs review
L["Scale of the minimized map."] = "Définit l'échelle de la carte minimisée."
L["Scale of the POI Icons on the Map."] = "Définit l'échelle des icônes des points d'intérêt sur la carte."
L["Size on the Battle Map"] = "Taille sur la carte de bataille"
L["Size on the World Map"] = "Taille sur la carte du monde"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Le module CarteLocale vous permet de changer le style de la carte locale (ou tactique) en enlevant les textures inutiles ou les objectifs JcJ."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Le module des coordonnées ajoute sur la fenêtre de la carte du monde les coordonnées actuelles de votre personnage ainsi que ceux de votre curseur."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Le module d'antibrouillard enlève le brouillard de guerre de la carte du monde, affichant ainsi tout ce qui se trouve dans les zones qui vous sont inconnues."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Le module Icônes de groupe vous permet de redimensionner les icônes du groupe et du raid de la carte du monde."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Le module des cartes d'instance vous permet de voir les cartes des champs de bataille et des instances du jeu sans être dans forcément dans ces instances."
L["The transparency of the big map."] = "Définit la transparence de la grande carte."
L["The transparency of the minimized map."] = "Définit la transparence de la carte minimisée."
L["Turn on debugging for the FogClear Module."] = "Active le débogage pour le module Antibrouillard."
L["Wrath Instances"] = "Instances de Lich King"
L["Wrath Raids"] = "Raids de Lich King"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Vous pouvez modifier la transparence de la carte du monde afin de continuer à voir l'environnement du jeu quand vous consultez la carte."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Vous pouvez ici déterminer la précision des coordonnées. Par exemple, si vous voulez des coordonnées très précises, mettez la valeur à 2."
